#!/bin/bash

check() {
    # Only include this module if it's a live boot
    return 0
}

depends() { 
    echo "dmsquash-live";
}

install() {
    # Force inclusion of needed binaries
    inst_multiple basename mkdir mount

    # Install the hook into the 'pre-pivot' stage
    inst_hook pre-pivot 99 "$moddir/mount-layers.sh"
}
